@@ -36,6 +36,17 @@ class Environment(object):
             '_user_auth_key': self.user_auth_key or ''
         }
 
+    def __getstate__(self):
+        return self.__dict__
+
+    def __setstate__(self, state):
+        now = ApiClient.get_timestamp()
+
+        if now > state['date']:
+            state['date'] = now
+
+        self.__dict__.update(state)
+
 
 class ApiResult(object):
     def __init__(self, func, params=None, post=None):
