@@ -7,6 +7,7 @@ from pytz import timezone
 from floraconcierge import errors
 
 
+
 # If int value is greater then this constant, object will have field ${field}_date which will be datetime type.
 # Date 05.11.1985. Too big value for usual usage and fine date :)
 MIN_INT_TO_DATETIME = 500000000
@@ -70,7 +71,10 @@ class Object(object):
         self.__dict__.update(extra)
 
     def __repr__(self):
-        return '<%s %s>' % (self.__class__.__name__, pformat(self.__dict__))
+        if not hasattr(self, '_repr_cache'):
+            setattr(self, '_repr_cache', '<%s %s>' % (self.__class__.__name__, pformat(self.__dict__)))
+
+        return getattr(self, '_repr_cache')
 
     def todict(self):
         return self.__dict__
